Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Stmt ¶
type Stmt struct {
// contains filtered or unexported fields
}
func (*Stmt) CheckNamedValue ¶
func (stmt *Stmt) CheckNamedValue(v *driver.NamedValue) error
type TDengineDriver ¶
type TDengineDriver struct{}
TDengineDriver is exported to make the driver directly accessible. In general the driver is used via the database/sql package.
Source Files
¶
- connection.go
- connector.go
- driver.go
- dsn.go
- rows.go
- statement.go
Click to show internal directories.
Click to hide internal directories.