Documentation
¶
Index ¶
- Constants
- Variables
- func WriteUint16(buffer *bytes.Buffer, v uint16)
- func WriteUint32(buffer *bytes.Buffer, v uint32)
- func WriteUint64(buffer *bytes.Buffer, v uint64)
- type BadConnError
- type Stmt
- type StmtAddBatchRequest
- type StmtAddBatchResponse
- type StmtBindResponse
- type StmtCloseRequest
- type StmtCloseResponse
- type StmtExecRequest
- type StmtExecResponse
- type StmtGetColFieldsRequest
- type StmtGetColFieldsResponse
- type StmtInitReq
- type StmtInitResp
- type StmtPrepareRequest
- type StmtPrepareResponse
- type StmtUseResultRequest
- type StmtUseResultResponse
- type TDengineDriver
- type WSAction
- type WSConnectReq
- type WSConnectResp
- type WSFetchBlockReq
- type WSFetchReq
- type WSFetchResp
- type WSFreeResultReq
- type WSQueryReq
- type WSQueryResp
Constants ¶
const ( WSConnect = "conn" WSQuery = "query" WSFetch = "fetch" WSFetchBlock = "fetch_block" WSFreeResult = "free_result" STMTInit = "init" STMTPrepare = "prepare" STMTAddBatch = "add_batch" STMTExec = "exec" STMTClose = "close" STMTGetColFields = "get_col_fields" STMTUseResult = "use_result" )
const (
BindMessage = 2
)
Variables ¶
Functions ¶
Types ¶
type BadConnError ¶
type BadConnError struct {
// contains filtered or unexported fields
}
func NewBadConnError ¶
func NewBadConnError(err error) *BadConnError
func NewBadConnErrorWithCtx ¶
func NewBadConnErrorWithCtx(err error, ctx string) *BadConnError
func (*BadConnError) Error ¶
func (e *BadConnError) Error() string
func (*BadConnError) Unwrap ¶
func (*BadConnError) Unwrap() error
type Stmt ¶
type Stmt struct {
// contains filtered or unexported fields
}
func (*Stmt) CheckNamedValue ¶
func (stmt *Stmt) CheckNamedValue(v *driver.NamedValue) error
type StmtAddBatchRequest ¶
type StmtAddBatchResponse ¶
type StmtBindResponse ¶
type StmtCloseRequest ¶
type StmtCloseResponse ¶
type StmtExecRequest ¶
type StmtExecResponse ¶
type StmtGetColFieldsRequest ¶
type StmtGetColFieldsResponse ¶
type StmtInitResp ¶
type StmtPrepareRequest ¶
type StmtPrepareResponse ¶
type StmtUseResultRequest ¶
type StmtUseResultResponse ¶
type StmtUseResultResponse struct {
Code int `json:"code"`
Message string `json:"message"`
Action string `json:"action"`
ReqID uint64 `json:"req_id"`
Timing int64 `json:"timing"`
StmtID uint64 `json:"stmt_id"`
ResultID uint64 `json:"result_id"`
FieldsCount int `json:"fields_count"`
FieldsNames []string `json:"fields_names"`
FieldsTypes []uint8 `json:"fields_types"`
FieldsLengths []int64 `json:"fields_lengths"`
Precision int `json:"precision"`
}
type TDengineDriver ¶
type TDengineDriver struct{}
TDengineDriver is exported to make the driver directly accessible. In general the driver is used via the database/sql package.
type WSAction ¶
type WSAction struct {
Action string `json:"action"`
Args json.RawMessage `json:"args"`
}
type WSConnectReq ¶
type WSConnectResp ¶
type WSFetchBlockReq ¶
type WSFetchResp ¶
type WSFreeResultReq ¶
type WSQueryResp ¶
type WSQueryResp struct {
Code int `json:"code"`
Message string `json:"message"`
Action string `json:"action"`
ReqID uint64 `json:"req_id"`
Timing int64 `json:"timing"`
ID uint64 `json:"id"`
IsUpdate bool `json:"is_update"`
AffectedRows int `json:"affected_rows"`
FieldsCount int `json:"fields_count"`
FieldsNames []string `json:"fields_names"`
FieldsTypes []uint8 `json:"fields_types"`
FieldsLengths []int64 `json:"fields_lengths"`
Precision int `json:"precision"`
}
Source Files
¶
- connection.go
- connector.go
- driver.go
- dsn.go
- error.go
- proto.go
- rows.go
- statement.go
Click to show internal directories.
Click to hide internal directories.